package com.zhongzheng.modules.recruit.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.StrUtil;
import com.zhongzheng.common.utils.DateUtils;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.github.pagehelper.Page;
import com.zhongzheng.modules.recruit.bo.RecruitInterviewMessageAddBo;
import com.zhongzheng.modules.recruit.bo.RecruitInterviewMessageQueryBo;
import com.zhongzheng.modules.recruit.bo.RecruitInterviewMessageEditBo;
import com.zhongzheng.modules.recruit.domain.RecruitInterviewMessage;
import com.zhongzheng.modules.recruit.mapper.RecruitInterviewMessageMapper;
import com.zhongzheng.modules.recruit.vo.RecruitInterviewMessageVo;
import com.zhongzheng.modules.recruit.service.IRecruitInterviewMessageService;

import java.util.Collection;
import java.util.Collections;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 【请填写功能名称】Service业务层处理
 *
 * @author ruoyi
 * @date 2021-09-15
 */
@Service
public class RecruitInterviewMessageServiceImpl extends ServiceImpl<RecruitInterviewMessageMapper, RecruitInterviewMessage> implements IRecruitInterviewMessageService {

    @Override
    public RecruitInterviewMessageVo queryById(Long id){
        RecruitInterviewMessage db = this.baseMapper.selectById(id);
        return BeanUtil.toBean(db, RecruitInterviewMessageVo.class);
    }

    @Override
    public List<RecruitInterviewMessageVo> queryList(RecruitInterviewMessageQueryBo bo) {
        LambdaQueryWrapper<RecruitInterviewMessage> lqw = Wrappers.lambdaQuery();
        lqw.eq(bo.getInterviewId() != null, RecruitInterviewMessage::getInterviewId, bo.getInterviewId());
        lqw.eq(bo.getUserId() != null, RecruitInterviewMessage::getUserId, bo.getUserId());
        lqw.eq(bo.getLookStatus() != null, RecruitInterviewMessage::getLookStatus, bo.getLookStatus());
        return entity2Vo(this.list(lqw));
    }

    /**
    * 实体类转化成视图对象
    *
    * @param collection 实体类集合
    * @return
    */
    private List<RecruitInterviewMessageVo> entity2Vo(Collection<RecruitInterviewMessage> collection) {
        List<RecruitInterviewMessageVo> voList = collection.stream()
                .map(any -> BeanUtil.toBean(any, RecruitInterviewMessageVo.class))
                .collect(Collectors.toList());
        if (collection instanceof Page) {
            Page<RecruitInterviewMessage> page = (Page<RecruitInterviewMessage>)collection;
            Page<RecruitInterviewMessageVo> pageVo = new Page<>();
            BeanUtil.copyProperties(page,pageVo);
            pageVo.addAll(voList);
            voList = pageVo;
        }
        return voList;
    }

    @Override
    public Boolean insertByAddBo(RecruitInterviewMessageAddBo bo) {
        RecruitInterviewMessage add = BeanUtil.toBean(bo, RecruitInterviewMessage.class);
        validEntityBeforeSave(add);
        add.setCreateTime(DateUtils.getNowTime());
        add.setUpdateTime(DateUtils.getNowTime());
        return this.save(add);
    }

    @Override
    public Boolean updateByEditBo(RecruitInterviewMessageEditBo bo) {
        RecruitInterviewMessage update = BeanUtil.toBean(bo, RecruitInterviewMessage.class);
        validEntityBeforeSave(update);
        update.setUpdateTime(DateUtils.getNowTime());
        return this.updateById(update);
    }

    /**
     * 保存前的数据校验
     *
     * @param entity 实体类数据
     */
    private void validEntityBeforeSave(RecruitInterviewMessage entity){
        //TODO 做一些数据校验,如唯一约束
    }

    @Override
    public Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid) {
        if(isValid){
            //TODO 做一些业务上的校验,判断是否需要校验
        }
        return this.removeByIds(ids);
    }
}
